@@ -23,7 +23,7 @@
 
 namespace Analitza {
 class Expression;
-};
+}
 
 /**
  * \class BlockMatrixCommand
@@ -51,7 +51,7 @@ class Expression;
 class BlockMatrixCommand: public Analitza::FunctionDefinition
 {
 public:
-    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args);
+    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args) override;
     
     static const QString id;
     static const Analitza::ExpressionType type;
@@ -72,7 +72,7 @@ public:
 class BlockDiagonalMatrixCommand: public Analitza::FunctionDefinition
 {
 public:
-    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args);
+    virtual Analitza::Expression operator()(const QList< Analitza::Expression >& args) override;
 
     static const QString id;
     static const Analitza::ExpressionType type;
